kenchi\.outlier\_detection\.mixture\_distns module
==================================================

.. automodule:: kenchi.outlier_detection.mixture_distns
    :members:
    :undoc-members:
    :show-inheritance:
